bayespy.inference.vmp.nodes.gaussian.GaussianGammaMoments.add_converter
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaMoments.add_converter